fnss.topologies.topology.write_topology — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »

# fnss.topologies.topology.write_topology

`write_topology`(topology, path, encoding='utf-8', prettyprint=True)

  Write a topology object on an XML file

  Parameters: | topology : Topology The topology object to write path : str The file ob which the topology will be written encoding : str, optional The encoding of the target file prettyprint : bool, optional Indent the XML code in the output file

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »